@@ -34,5 +34,5 @@ def getnode():
     if hasattr(config, "id_client"):
         return config.id_client
     else:
-        random.seed(platform.node() + get_mac())
-        return str(random.randint(1, 9999999)).zfill(7)
+        random.seed(platform.node() + str(get_mac()))
+        return str(random.randint(1, 999999999999)).zfill(7)
